@@ -5,8 +5,8 @@ HTMLWidgets.widget({
   factory: function(el, width, height) {
     return {
       renderValue: function(x) {
-        var tag_js = "<script src='http://d335w9rbwpvuxm.cloudfront.net/semantic.min.js'></script>"
-        var tag_css = "<link href='http://d335w9rbwpvuxm.cloudfront.net/semantic.min.css' rel='stylesheet'>"
+        var tag_js = "<script src='https://d335w9rbwpvuxm.cloudfront.net/semantic.min.js'></script>"
+        var tag_css = "<link href='https://d335w9rbwpvuxm.cloudfront.net/semantic.min.css' rel='stylesheet'>"
         el.innerHTML = x.ui + tag_js + tag_css;
         },
 
